# -*- coding: utf-8 -*-
# Copyright: See the LICENSE file.

# factory.django needs a configured Django.
from .test_django import *

from .test_base import *
from .test_declarations import *
from .test_docs_internals import *
from .test_faker import *
from .test_fuzzy import *
from .test_helpers import *
from .test_using import *
from .test_utils import *
from .test_alchemy import *
from .test_mongoengine import *
